@@ -66,8 +66,8 @@ C<Rose::HTML::Form::Field::SelectBox> is an object representation of a
 select box field in an HTML form.
 
 This class inherits from, and follows the conventions of,
-C<Rose::HTML::Form::Field>. Inherited methods that are not overridden will not
-be documented a second time here.  See the C<Rose::HTML::Form::Field>
+L<Rose::HTML::Form::Field>. Inherited methods that are not overridden will not
+be documented a second time here.  See the L<Rose::HTML::Form::Field>
 documentation for more information.
 
 =head1 HTML ATTRIBUTES
@@ -134,8 +134,8 @@ Convenience alias for C<add_options()>.
 
 Adds options to the select box.  OPTIONS may be a reference to a hash of
 value/label pairs, a reference to an array of values, or a list of objects
-that are of, or inherit from, the classes C<Rose::HTML::Form::Field::Option>
-or C<Rose::HTML::Form::Field::OptionGroup>. Passing an odd number of items in
+that are of, or inherit from, the classes L<Rose::HTML::Form::Field::Option>
+or L<Rose::HTML::Form::Field::OptionGroup>. Passing an odd number of items in
 the value/label argument list causes a fatal error. Options passed as a hash
 reference are sorted by value according to the default behavior of Perl's
 built-in C<sort()> function.  Options are added to the end of the existing
@@ -179,7 +179,7 @@ option exists.
 Get or set the full list of options in the select box.  OPTIONS may be a
 reference to a hash of value/label pairs, a reference to an array of values,
 or a list of objects that are of, or inherit from, the classes
-C<Rose::HTML::Form::Field::Option> or C<Rose::HTML::Form::Field::OptionGroup>.
+L<Rose::HTML::Form::Field::Option> or L<Rose::HTML::Form::Field::OptionGroup>.
 Passing an odd number of items in the value/label argument list causes a fatal
 error. Options passed as a hash reference are sorted by value according to the
 default behavior of Perl's built-in C<sort()> function.
@@ -195,12 +195,12 @@ Example:
         labels  => { apple => 'Apple', pear => 'Pear' });
 
 Remember that methods are called in the order that they appear in the
-constructor arguments (see the C<Rose::Object> documentation), so C<options()>
+constructor arguments (see the L<Rose::Object> documentation), so C<options()>
 will be called before C<labels()> in the example above.  This is important; it
 will not work in the opposite order.
 
-Returns a list of the select box's C<Rose::HTML::Form::Field::Option> and/or
-C<Rose::HTML::Form::Field::OptionGroup> objects in list context, or a
+Returns a list of the select box's L<Rose::HTML::Form::Field::Option> and/or
+L<Rose::HTML::Form::Field::OptionGroup> objects in list context, or a
 reference to an array of the same in scalar context. These are the actual
 objects used in the field. Modifying them will modify the field itself.
 
@@ -234,6 +234,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2005 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
